@@ -12,7 +12,6 @@ import hashlib
 from json_logic import jsonLogic
 from enum import Enum
 
-
 DT_FMT_HMSf = '%H%M%S%f'
 
 
@@ -555,3 +554,47 @@ def invoke_conditional_task(conf, condition, true_task, false_task):
         return true_task
     else:
         return false_task
+
+
+def invoke_start_task(conf, condition=None, true_task=None, false_task=None, default_task=None):
+    """ This task is invoked as starting point of any workflow
+        - this task will run start task if triggered directly
+        - will trigger next task if triggered from delay task (delay mysql tbl)
+        params:
+        1. conf: conf object
+        2. condition: condition object
+        3. true_task: task to be triggered if condition is true
+        4. false_task: task to be triggered if condition is false
+        5. default_task: default task to be triggered if there is no condition or next task found
+        """
+
+    if conf.get('next_task', ''):
+        return conf.get('next_task')
+    elif condition and true_task and false_task:
+        task = invoke_conditional_task(conf, condition, true_task, false_task)
+        return task
+    elif default_task:
+        return default_task
+
+
+def add_delay_task(conf, current_task_id, vtiger_access):
+    """ This task is useful to insert delayed task data in MySQL database.
+            params:
+            1. conf: conf object
+            2. current_task_id: current task id
+            3. vtiger_access: vtiger_access to pass configurations
+            """
+    delay_task_configs = conf['delay_task_configs']
+    if current_task_id in delay_task_configs:
+        delay_task_configs = delay_task_configs[current_task_id]
+        print("delay_task_configs : ", delay_task_configs)
+        payload = {
+            "conf": conf,
+            "delay_task_configs": delay_task_configs
+        }
+
+    endpoint = '{service_url}/api/v1/add_delayed_data'.format(service_url=vtiger_access.get('service_url'))
+    headers = {'content_type': 'application/json'}
+
+    response, status = invoke_http_request(endpoint, 'POST', headers, json_data=payload, timeout=61)
+    print("response from add delayed task", response, "status", status)
